import typer
import random
from rich.console import Console
from rich.align import Align
from .. import utils

console = Console()

WRITING_TIPS = [
    "Done is better than perfect. Start writing, even if it's just a rough draft.",
    "Write first, edit later. Don't let your inner critic slow you down.",
    "The 'Pomodoro Technique' (25 mins writing, 5 mins break) can work wonders for focus.",
    "A clear outline is half the battle won. Spend time on your structure.",
    "Read your writing aloud to catch awkward phrasing and errors.",
    "Break down large chapters into smaller, manageable sections.",
    "Cite as you write. It saves a lot of time and headache later.",
    "Don't be afraid to take a break. A fresh mind solves problems faster.",
]

def meow():
    """显示一条随机的学术写作小贴士。"""
    tip = random.choice(WRITING_TIPS)
    console.print(f"🐾 [magenta]Meow![/magenta] A little tip for you:\n\n[italic]\"{tip}\"[/italic]")

def woof():
    """快速汇报项目统计信息。"""
    console.print("🐾 [bold]Woof! Here's the report on your project:[/bold]")
    try:
        project_paths = utils.get_project_paths()
        
        manuscript_files = list(project_paths["manuscript"].glob("*.md"))
        figure_files = list(project_paths["figures"].glob("*"))

        # 统计 bib 文件中的条目数
        bib_entries_count = 0
        try:
            with open(project_paths["frontmatter"], 'r', encoding='utf-8') as f:
                docs = list(utils.yaml.load_all(f))
            bib_paths_config = docs[0].get("bibliography", [])
            if isinstance(bib_paths_config, str):
                bib_paths_config = [bib_paths_config]
            
            from pybtex.database import parse_file as parse_bib_file
            for bib_path_str in bib_paths_config:
                bib_path = project_paths["root"] / bib_path_str
                if bib_path.exists():
                    bib_data = parse_bib_file(str(bib_path), 'bibtex')
                    bib_entries_count += len(bib_data.entries)
        except Exception:
            # 如果解析失败, 忽略
            pass

        console.print(f"- [cyan]Chapters[/cyan]: {len(manuscript_files) - 1} (+1 frontmatter file)")
        console.print(f"- [cyan]Figures[/cyan]: {len(figure_files)}")
        console.print(f"- [cyan]Citations[/cyan]: {bib_entries_count} entries found in .bib files")
        console.print("\nKeep up the great work!")

    except typer.Exit:
        # 捕获 get_project_paths 找不到项目时的退出异常
        console.print("[yellow]You need to be inside a PAW project directory for me to report on it.[/yellow]")
        

def show_paw():
    """显示爪印 ASCII 艺术。"""
    display_colored_art("center")
    console.print("PAW - Pandoc Academic Workflow", justify="center")
    console.print("\n[bold blue]Created by [italic]KawaroX[/italic][/bold blue]", justify="center")

def praise():
    """给予鼓励。"""
    console.print("You are! 📝✨")



colored_art = [
        "[rgb(0,0,0)]                   [/rgb(0,0,0)][rgb(26,26,26)] [/rgb(26,26,26)][rgb(61,61,61)]░[/rgb(61,61,61)][rgb(77,78,78)]░[/rgb(77,78,78)][rgb(81,81,81)]░[/rgb(81,81,81)][rgb(65,65,65)]░[/rgb(65,65,65)][rgb(40,40,40)] [/rgb(40,40,40)][rgb(12,12,12)] [/rgb(12,12,12)][rgb(0,0,0)]        [/rgb(0,0,0)][rgb(12,12,12)] [/rgb(12,12,12)][rgb(40,40,40)] [/rgb(40,40,40)][rgb(65,65,65)]░[/rgb(65,65,65)][rgb(81,81,81)]░[/rgb(81,81,81)][rgb(78,78,78)]░[/rgb(78,78,78)][rgb(61,61,61)]░[/rgb(61,61,61)][rgb(26,26,26)] [/rgb(26,26,26)][rgb(0,0,0)]                   [/rgb(0,0,0)]",
        "[rgb(0,0,0)]                 [/rgb(0,0,0)][rgb(68,68,68)]░[/rgb(68,68,68)][rgb(174,175,175)]▓[/rgb(174,175,175)][rgb(237,239,239)]█[/rgb(237,239,239)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(248,250,250)]█[/rgb(248,250,250)][rgb(222,223,223)]█[/rgb(222,223,223)][rgb(161,161,161)]▓[/rgb(161,161,161)][rgb(80,80,80)]░[/rgb(80,80,80)][rgb(11,11,11)] [/rgb(11,11,11)][rgb(0,0,0)]  [/rgb(0,0,0)][rgb(10,10,10)] [/rgb(10,10,10)][rgb(80,80,80)]░[/rgb(80,80,80)][rgb(160,160,160)]▓[/rgb(160,160,160)][rgb(222,223,223)]█[/rgb(222,223,223)][rgb(248,250,250)]█[/rgb(248,250,250)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(237,239,239)]█[/rgb(237,239,239)][rgb(174,175,175)]▓[/rgb(174,175,175)][rgb(69,69,69)]░[/rgb(69,69,69)][rgb(0,0,0)]                 [/rgb(0,0,0)]",
        "[rgb(0,0,0)]               [/rgb(0,0,0)][rgb(6,6,6)] [/rgb(6,6,6)][rgb(142,142,142)]▒[/rgb(142,142,142)][rgb(253,253,253)]█[/rgb(253,253,253)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(255,237,237)]█[/rgb(255,237,237)][rgb(255,218,218)]█[/rgb(255,218,218)][rgb(255,211,211)]██[/rgb(255,211,211)][rgb(255,214,214)]█[/rgb(255,214,214)][rgb(255,226,226)]█[/rgb(255,226,226)][rgb(255,247,247)]█[/rgb(255,247,247)][rgb(255,255,255)]██[/rgb(255,255,255)][rgb(212,212,212)]█[/rgb(212,212,212)][rgb(95,95,95)]░░[/rgb(95,95,95)][rgb(212,212,212)]█[/rgb(212,212,212)][rgb(255,255,255)]██[/rgb(255,255,255)][rgb(255,247,247)]█[/rgb(255,247,247)][rgb(255,226,226)]█[/rgb(255,226,226)][rgb(255,214,214)]█[/rgb(255,214,214)][rgb(255,211,211)]██[/rgb(255,211,211)][rgb(255,218,218)]█[/rgb(255,218,218)][rgb(255,237,237)]█[/rgb(255,237,237)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(253,253,253)]█[/rgb(253,253,253)][rgb(143,143,143)]▒[/rgb(143,143,143)][rgb(6,6,6)] [/rgb(6,6,6)][rgb(0,0,0)]               [/rgb(0,0,0)]",
        "[rgb(0,0,0)]               [/rgb(0,0,0)][rgb(131,131,131)]▒[/rgb(131,131,131)][rgb(255,255,255)]██[/rgb(255,255,255)][rgb(255,223,223)]█[/rgb(255,223,223)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,205,205)]█[/rgb(255,205,205)][rgb(255,204,204)]██[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,205,205)]█[/rgb(255,205,205)][rgb(255,228,228)]█[/rgb(255,228,228)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,228,228)]█[/rgb(255,228,228)][rgb(255,205,205)]█[/rgb(255,205,205)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,204,204)]██[/rgb(255,204,204)][rgb(255,205,205)]█[/rgb(255,205,205)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,223,223)]█[/rgb(255,223,223)][rgb(255,255,255)]██[/rgb(255,255,255)][rgb(131,131,131)]▒[/rgb(131,131,131)][rgb(0,0,0)]               [/rgb(0,0,0)]",
        "[rgb(0,0,0)]              [/rgb(0,0,0)][rgb(21,21,21)] [/rgb(21,21,21)][rgb(238,238,238)]█[/rgb(238,238,238)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(255,249,249)]█[/rgb(255,249,249)][rgb(255,208,208)]█[/rgb(255,208,208)][rgb(255,205,205)]███████[/rgb(255,205,205)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,237,237)]█[/rgb(255,237,237)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,237,237)]█[/rgb(255,237,237)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,205,205)]███████[/rgb(255,205,205)][rgb(255,208,208)]█[/rgb(255,208,208)][rgb(255,250,250)]█[/rgb(255,250,250)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(238,238,238)]█[/rgb(238,238,238)][rgb(22,22,22)] [/rgb(22,22,22)][rgb(0,0,0)]              [/rgb(0,0,0)]",
        "[rgb(0,0,0)]           [/rgb(0,0,0)][rgb(9,9,9)] [/rgb(9,9,9)][rgb(28,28,28)] [/rgb(28,28,28)][rgb(40,40,40)] [/rgb(40,40,40)][rgb(105,105,105)]▒[/rgb(105,105,105)][rgb(255,255,255)]██[/rgb(255,255,255)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,221,221)]█[/rgb(255,221,221)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,205,205)]██████[/rgb(255,205,205)][rgb(255,202,202)]█[/rgb(255,202,202)][rgb(255,235,235)]█[/rgb(255,235,235)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,235,235)]█[/rgb(255,235,235)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,205,205)]██████[/rgb(255,205,205)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,221,221)]█[/rgb(255,221,221)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,255,255)]██[/rgb(255,255,255)][rgb(105,105,105)]▒[/rgb(105,105,105)][rgb(40,40,40)] [/rgb(40,40,40)][rgb(28,28,28)] [/rgb(28,28,28)][rgb(9,9,9)] [/rgb(9,9,9)][rgb(0,0,0)]           [/rgb(0,0,0)]",
        "[rgb(0,0,0)]        [/rgb(0,0,0)][rgb(55,55,55)]░[/rgb(55,55,55)][rgb(131,131,131)]▒[/rgb(131,131,131)][rgb(189,191,191)]▓[/rgb(189,191,191)][rgb(219,220,220)]█[/rgb(219,220,220)][rgb(241,243,243)]█[/rgb(241,243,243)][rgb(248,250,250)]█[/rgb(248,250,250)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,252,252)]█[/rgb(255,252,252)][rgb(255,226,226)]█[/rgb(255,226,226)][rgb(255,208,208)]█[/rgb(255,208,208)][rgb(255,204,204)]██[/rgb(255,204,204)][rgb(255,203,203)]██[/rgb(255,203,203)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,221,221)]█[/rgb(255,221,221)][rgb(255,251,251)]█[/rgb(255,251,251)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,252,252)]█[/rgb(255,252,252)][rgb(255,222,222)]█[/rgb(255,222,222)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,203,203)]███[/rgb(255,203,203)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,208,208)]█[/rgb(255,208,208)][rgb(255,226,226)]█[/rgb(255,226,226)][rgb(255,251,251)]█[/rgb(255,251,251)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(248,250,250)]█[/rgb(248,250,250)][rgb(241,242,242)]█[/rgb(241,242,242)][rgb(218,220,220)]█[/rgb(218,220,220)][rgb(189,191,191)]▓[/rgb(189,191,191)][rgb(130,131,131)]▒[/rgb(130,131,131)][rgb(55,55,55)]░[/rgb(55,55,55)][rgb(0,0,0)]        [/rgb(0,0,0)]",
        "[rgb(0,0,0)]      [/rgb(0,0,0)][rgb(46,46,46)] [/rgb(46,46,46)][rgb(185,185,185)]▓[/rgb(185,185,185)][rgb(252,253,253)]█[/rgb(252,253,253)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(255,252,252)]█[/rgb(255,252,252)][rgb(255,242,242)]█[/rgb(255,242,242)][rgb(255,238,238)]█[/rgb(255,238,238)][rgb(255,241,241)]█[/rgb(255,241,241)][rgb(255,248,248)]█[/rgb(255,248,248)][rgb(255,255,255)]█████[/rgb(255,255,255)][rgb(255,247,247)]█[/rgb(255,247,247)][rgb(255,235,235)]█[/rgb(255,235,235)][rgb(255,229,229)]█[/rgb(255,229,229)][rgb(255,227,227)]█[/rgb(255,227,227)][rgb(255,231,231)]█[/rgb(255,231,231)][rgb(255,242,242)]█[/rgb(255,242,242)][rgb(255,255,255)]████████[/rgb(255,255,255)][rgb(255,242,242)]█[/rgb(255,242,242)][rgb(255,231,231)]█[/rgb(255,231,231)][rgb(255,227,227)]█[/rgb(255,227,227)][rgb(255,229,229)]█[/rgb(255,229,229)][rgb(255,235,235)]█[/rgb(255,235,235)][rgb(255,248,248)]█[/rgb(255,248,248)][rgb(255,255,255)]█████[/rgb(255,255,255)][rgb(255,248,248)]█[/rgb(255,248,248)][rgb(255,241,241)]█[/rgb(255,241,241)][rgb(255,238,238)]█[/rgb(255,238,238)][rgb(255,243,243)]█[/rgb(255,243,243)][rgb(255,251,251)]█[/rgb(255,251,251)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(252,253,253)]█[/rgb(252,253,253)][rgb(184,184,184)]▓[/rgb(184,184,184)][rgb(46,46,46)] [/rgb(46,46,46)][rgb(0,0,0)]      [/rgb(0,0,0)]",
        "[rgb(0,0,0)]     [/rgb(0,0,0)][rgb(48,48,48)] [/rgb(48,48,48)][rgb(234,234,234)]█[/rgb(234,234,234)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(255,240,240)]█[/rgb(255,240,240)][rgb(255,213,213)]█[/rgb(255,213,213)][rgb(255,205,205)]█[/rgb(255,205,205)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,207,207)]█[/rgb(255,207,207)][rgb(255,217,217)]█[/rgb(255,217,217)][rgb(255,239,239)]█[/rgb(255,239,239)][rgb(255,255,255)]████████████[/rgb(255,255,255)][rgb(255,254,254)]██[/rgb(255,254,254)][rgb(255,255,255)]████████████[/rgb(255,255,255)][rgb(255,239,239)]█[/rgb(255,239,239)][rgb(255,217,217)]█[/rgb(255,217,217)][rgb(255,207,207)]█[/rgb(255,207,207)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,205,205)]█[/rgb(255,205,205)][rgb(255,213,213)]█[/rgb(255,213,213)][rgb(255,239,239)]█[/rgb(255,239,239)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(234,234,234)]█[/rgb(234,234,234)][rgb(48,48,48)] [/rgb(48,48,48)][rgb(0,0,0)]     [/rgb(0,0,0)]",
        "[rgb(0,0,0)]     [/rgb(0,0,0)][rgb(158,158,158)]▓[/rgb(158,158,158)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(255,246,246)]█[/rgb(255,246,246)][rgb(255,206,206)]█[/rgb(255,206,206)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,205,205)]█████[/rgb(255,205,205)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,205,205)]█[/rgb(255,205,205)][rgb(255,232,232)]█[/rgb(255,232,232)][rgb(255,255,255)]███████[/rgb(255,255,255)][rgb(255,248,248)]█[/rgb(255,248,248)][rgb(255,234,234)]█[/rgb(255,234,234)][rgb(255,223,223)]█[/rgb(255,223,223)][rgb(255,216,216)]█[/rgb(255,216,216)][rgb(255,213,213)]██[/rgb(255,213,213)][rgb(255,216,216)]█[/rgb(255,216,216)][rgb(255,223,223)]█[/rgb(255,223,223)][rgb(255,234,234)]█[/rgb(255,234,234)][rgb(255,248,248)]█[/rgb(255,248,248)][rgb(255,255,255)]███████[/rgb(255,255,255)][rgb(255,232,232)]█[/rgb(255,232,232)][rgb(255,205,205)]█[/rgb(255,205,205)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,205,205)]█████[/rgb(255,205,205)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,206,206)]█[/rgb(255,206,206)][rgb(255,246,246)]█[/rgb(255,246,246)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(159,159,159)]▓[/rgb(159,159,159)][rgb(0,0,0)]     [/rgb(0,0,0)]",
        "[rgb(0,0,0)]     [/rgb(0,0,0)][rgb(152,152,152)]▒[/rgb(152,152,152)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(255,248,248)]█[/rgb(255,248,248)][rgb(255,208,208)]█[/rgb(255,208,208)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,205,205)]██████[/rgb(255,205,205)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,214,214)]█[/rgb(255,214,214)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,252,252)]█[/rgb(255,252,252)][rgb(255,228,228)]█[/rgb(255,228,228)][rgb(255,207,207)]█[/rgb(255,207,207)][rgb(255,203,203)]██[/rgb(255,203,203)][rgb(255,204,204)]████[/rgb(255,204,204)][rgb(255,203,203)]██[/rgb(255,203,203)][rgb(255,207,207)]█[/rgb(255,207,207)][rgb(255,228,228)]█[/rgb(255,228,228)][rgb(255,252,252)]█[/rgb(255,252,252)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,215,215)]█[/rgb(255,215,215)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,205,205)]██████[/rgb(255,205,205)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,207,207)]█[/rgb(255,207,207)][rgb(255,248,248)]█[/rgb(255,248,248)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(153,153,153)]▓[/rgb(153,153,153)][rgb(0,0,0)]     [/rgb(0,0,0)]",
        "[rgb(0,0,0)]     [/rgb(0,0,0)][rgb(49,49,49)] [/rgb(49,49,49)][rgb(243,243,243)]█[/rgb(243,243,243)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(255,239,239)]█[/rgb(255,239,239)][rgb(255,210,210)]█[/rgb(255,210,210)][rgb(255,203,203)]██[/rgb(255,203,203)][rgb(255,204,204)]███[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,232,232)]█[/rgb(255,232,232)][rgb(255,255,255)]█████[/rgb(255,255,255)][rgb(255,225,225)]█[/rgb(255,225,225)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,205,205)]████████[/rgb(255,205,205)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,225,225)]█[/rgb(255,225,225)][rgb(255,255,255)]█████[/rgb(255,255,255)][rgb(255,231,231)]█[/rgb(255,231,231)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,204,204)]████[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,210,210)]█[/rgb(255,210,210)][rgb(255,239,239)]█[/rgb(255,239,239)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(243,243,243)]█[/rgb(243,243,243)][rgb(50,50,50)] [/rgb(50,50,50)][rgb(0,0,0)]     [/rgb(0,0,0)]",
        "[rgb(0,0,0)]      [/rgb(0,0,0)][rgb(77,77,77)]░[/rgb(77,77,77)][rgb(238,238,238)]█[/rgb(238,238,238)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(255,252,252)]█[/rgb(255,252,252)][rgb(255,235,235)]█[/rgb(255,235,235)][rgb(255,222,222)]█[/rgb(255,222,222)][rgb(255,215,215)]█[/rgb(255,215,215)][rgb(255,214,214)]█[/rgb(255,214,214)][rgb(255,216,216)]█[/rgb(255,216,216)][rgb(255,224,224)]█[/rgb(255,224,224)][rgb(255,242,242)]█[/rgb(255,242,242)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,247,247)]█[/rgb(255,247,247)][rgb(255,234,234)]█[/rgb(255,234,234)][rgb(255,207,207)]█[/rgb(255,207,207)][rgb(255,205,205)]████████████[/rgb(255,205,205)][rgb(255,207,207)]█[/rgb(255,207,207)][rgb(255,234,234)]█[/rgb(255,234,234)][rgb(255,247,247)]█[/rgb(255,247,247)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,242,242)]█[/rgb(255,242,242)][rgb(255,225,225)]█[/rgb(255,225,225)][rgb(255,216,216)]█[/rgb(255,216,216)][rgb(255,214,214)]█[/rgb(255,214,214)][rgb(255,215,215)]█[/rgb(255,215,215)][rgb(255,222,222)]█[/rgb(255,222,222)][rgb(255,235,235)]█[/rgb(255,235,235)][rgb(255,252,252)]█[/rgb(255,252,252)][rgb(255,255,255)]█[/rgb(255,255,255)][rgb(238,238,238)]█[/rgb(238,238,238)][rgb(77,77,77)]░[/rgb(77,77,77)][rgb(0,0,0)]      [/rgb(0,0,0)]",
        "[rgb(0,0,0)]       [/rgb(0,0,0)][rgb(49,49,49)] [/rgb(49,49,49)][rgb(185,185,185)]▓[/rgb(185,185,185)][rgb(254,254,254)]█[/rgb(254,254,254)][rgb(255,255,255)]███[/rgb(255,255,255)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,253,253)]█[/rgb(255,253,253)][rgb(255,236,236)]█[/rgb(255,236,236)][rgb(255,217,217)]█[/rgb(255,217,217)][rgb(255,207,207)]█[/rgb(255,207,207)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,205,205)]██████████████[/rgb(255,205,205)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,207,207)]█[/rgb(255,207,207)][rgb(255,217,217)]█[/rgb(255,217,217)][rgb(255,236,236)]█[/rgb(255,236,236)][rgb(255,253,253)]█[/rgb(255,253,253)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,255,255)]███[/rgb(255,255,255)][rgb(254,255,255)]█[/rgb(254,255,255)][rgb(185,185,185)]▓[/rgb(185,185,185)][rgb(49,49,49)] [/rgb(49,49,49)][rgb(0,0,0)]       [/rgb(0,0,0)]",
        "[rgb(0,0,0)]         [/rgb(0,0,0)][rgb(66,66,66)]░[/rgb(66,66,66)][rgb(171,171,171)]▓[/rgb(171,171,171)][rgb(234,234,234)]█[/rgb(234,234,234)][rgb(255,255,255)]█████[/rgb(255,255,255)][rgb(255,249,249)]█[/rgb(255,249,249)][rgb(255,217,217)]█[/rgb(255,217,217)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,205,205)]██████████████████[/rgb(255,205,205)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,218,218)]█[/rgb(255,218,218)][rgb(255,249,249)]█[/rgb(255,249,249)][rgb(255,255,255)]█████[/rgb(255,255,255)][rgb(234,234,234)]█[/rgb(234,234,234)][rgb(172,172,172)]▓[/rgb(172,172,172)][rgb(67,67,67)]░[/rgb(67,67,67)][rgb(0,0,0)]         [/rgb(0,0,0)]",
        "[rgb(0,0,0)]           [/rgb(0,0,0)][rgb(162,162,162)]▓[/rgb(162,162,162)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,219,219)]█[/rgb(255,219,219)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,205,205)]██████████████████████[/rgb(255,205,205)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,219,219)]█[/rgb(255,219,219)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(163,163,163)]▓[/rgb(163,163,163)][rgb(0,0,0)]           [/rgb(0,0,0)]",
        "[rgb(0,0,0)]          [/rgb(0,0,0)][rgb(19,19,19)] [/rgb(19,19,19)][rgb(234,234,234)]█[/rgb(234,234,234)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,216,216)]█[/rgb(255,216,216)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,205,205)]██████████████████████[/rgb(255,205,205)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,216,216)]█[/rgb(255,216,216)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,255,255)]████[/rgb(255,255,255)][rgb(235,235,235)]█[/rgb(235,235,235)][rgb(20,20,20)] [/rgb(20,20,20)][rgb(0,0,0)]          [/rgb(0,0,0)]",
        "[rgb(0,0,0)]          [/rgb(0,0,0)][rgb(16,16,16)] [/rgb(16,16,16)][rgb(231,231,231)]█[/rgb(231,231,231)][rgb(255,255,255)]█████[/rgb(255,255,255)][rgb(255,246,246)]█[/rgb(255,246,246)][rgb(255,216,216)]█[/rgb(255,216,216)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,204,204)]███[/rgb(255,204,204)][rgb(255,205,205)]███[/rgb(255,205,205)][rgb(255,204,204)]██[/rgb(255,204,204)][rgb(255,203,203)]██[/rgb(255,203,203)][rgb(255,204,204)]██[/rgb(255,204,204)][rgb(255,205,205)]███[/rgb(255,205,205)][rgb(255,204,204)]███[/rgb(255,204,204)][rgb(255,203,203)]█[/rgb(255,203,203)][rgb(255,204,204)]█[/rgb(255,204,204)][rgb(255,216,216)]█[/rgb(255,216,216)][rgb(255,246,246)]█[/rgb(255,246,246)][rgb(255,255,255)]█████[/rgb(255,255,255)][rgb(231,231,231)]█[/rgb(231,231,231)][rgb(16,16,16)] [/rgb(16,16,16)][rgb(0,0,0)]          [/rgb(0,0,0)]",
        "[rgb(0,0,0)]           [/rgb(0,0,0)][rgb(111,111,111)]▒[/rgb(111,111,111)][rgb(255,255,255)]██████[/rgb(255,255,255)][rgb(255,253,253)]█[/rgb(255,253,253)][rgb(255,240,240)]█[/rgb(255,240,240)][rgb(255,226,226)]█[/rgb(255,226,226)][rgb(255,217,217)]█[/rgb(255,217,217)][rgb(255,211,211)]█[/rgb(255,211,211)][rgb(255,208,208)]█[/rgb(255,208,208)][rgb(255,207,207)]███[/rgb(255,207,207)][rgb(255,210,210)]█[/rgb(255,210,210)][rgb(255,214,214)]█[/rgb(255,214,214)][rgb(255,218,218)]█[/rgb(255,218,218)][rgb(255,219,219)]█[/rgb(255,219,219)][rgb(255,213,213)]█[/rgb(255,213,213)][rgb(255,210,210)]█[/rgb(255,210,210)][rgb(255,207,207)]███[/rgb(255,207,207)][rgb(255,208,208)]█[/rgb(255,208,208)][rgb(255,211,211)]█[/rgb(255,211,211)][rgb(255,216,216)]█[/rgb(255,216,216)][rgb(255,226,226)]█[/rgb(255,226,226)][rgb(255,240,240)]█[/rgb(255,240,240)][rgb(255,253,253)]█[/rgb(255,253,253)][rgb(255,255,255)]██████[/rgb(255,255,255)][rgb(112,112,112)]▒[/rgb(112,112,112)][rgb(0,0,0)]           [/rgb(0,0,0)]",
        "[rgb(0,0,0)]            [/rgb(0,0,0)][rgb(114,114,114)]▒[/rgb(114,114,114)][rgb(246,246,246)]█[/rgb(246,246,246)][rgb(255,255,255)]████████[/rgb(255,255,255)][rgb(255,252,252)]█[/rgb(255,252,252)][rgb(255,250,250)]█[/rgb(255,250,250)][rgb(255,248,248)]██[/rgb(255,248,248)][rgb(255,249,249)]█[/rgb(255,249,249)][rgb(255,252,252)]█[/rgb(255,252,252)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,255,255)]██[/rgb(255,255,255)][rgb(255,254,254)]█[/rgb(255,254,254)][rgb(255,251,251)]█[/rgb(255,251,251)][rgb(255,249,249)]█[/rgb(255,249,249)][rgb(255,248,248)]██[/rgb(255,248,248)][rgb(255,250,250)]█[/rgb(255,250,250)][rgb(255,252,252)]█[/rgb(255,252,252)][rgb(255,255,255)]████████[/rgb(255,255,255)][rgb(246,246,246)]█[/rgb(246,246,246)][rgb(115,115,115)]▒[/rgb(115,115,115)][rgb(0,0,0)]            [/rgb(0,0,0)]",
        "[rgb(0,0,0)]             [/rgb(0,0,0)][rgb(53,53,53)]░[/rgb(53,53,53)][rgb(165,165,165)]▓[/rgb(165,165,165)][rgb(238,238,238)]█[/rgb(238,238,238)][rgb(255,255,255)]████████████████████████████[/rgb(255,255,255)][rgb(238,238,238)]█[/rgb(238,238,238)][rgb(166,166,166)]▓[/rgb(166,166,166)][rgb(53,53,53)]░[/rgb(53,53,53)][rgb(0,0,0)]             [/rgb(0,0,0)]",
        "[rgb(0,0,0)]               [/rgb(0,0,0)][rgb(30,30,30)] [/rgb(30,30,30)][rgb(93,93,93)]░[/rgb(93,93,93)][rgb(149,149,149)]▒[/rgb(149,149,149)][rgb(182,182,182)]▓[/rgb(182,182,182)][rgb(211,211,211)]█[/rgb(211,211,211)][rgb(226,226,226)]█[/rgb(226,226,226)][rgb(237,237,237)]█[/rgb(237,237,237)][rgb(240,240,240)]█[/rgb(240,240,240)][rgb(234,234,234)]█[/rgb(234,234,234)][rgb(224,224,224)]█[/rgb(224,224,224)][rgb(211,211,211)]█[/rgb(211,211,211)][rgb(196,196,196)]▓[/rgb(196,196,196)][rgb(185,185,185)]▓[/rgb(185,185,185)][rgb(176,176,176)]▓[/rgb(176,176,176)][rgb(172,172,172)]▓▓[/rgb(172,172,172)][rgb(176,176,176)]▓[/rgb(176,176,176)][rgb(185,185,185)]▓[/rgb(185,185,185)][rgb(196,196,196)]▓[/rgb(196,196,196)][rgb(210,210,210)]█[/rgb(210,210,210)][rgb(224,224,224)]█[/rgb(224,224,224)][rgb(234,234,234)]█[/rgb(234,234,234)][rgb(240,240,240)]█[/rgb(240,240,240)][rgb(237,237,237)]█[/rgb(237,237,237)][rgb(226,226,226)]█[/rgb(226,226,226)][rgb(211,211,211)]█[/rgb(211,211,211)][rgb(182,182,182)]▓[/rgb(182,182,182)][rgb(149,149,149)]▒[/rgb(149,149,149)][rgb(93,93,93)]░[/rgb(93,93,93)][rgb(30,30,30)] [/rgb(30,30,30)][rgb(0,0,0)]               [/rgb(0,0,0)]",
        "[rgb(0,0,0)]                   [/rgb(0,0,0)][rgb(5,5,5)] [/rgb(5,5,5)][rgb(13,13,13)] [/rgb(13,13,13)][rgb(23,23,23)] [/rgb(23,23,23)][rgb(27,27,27)] [/rgb(27,27,27)][rgb(20,20,20)] [/rgb(20,20,20)][rgb(12,12,12)] [/rgb(12,12,12)][rgb(4,4,4)] [/rgb(4,4,4)][rgb(0,0,0)]        [/rgb(0,0,0)][rgb(4,4,4)] [/rgb(4,4,4)][rgb(12,12,12)] [/rgb(12,12,12)][rgb(20,20,20)] [/rgb(20,20,20)][rgb(27,27,27)] [/rgb(27,27,27)][rgb(23,23,23)] [/rgb(23,23,23)][rgb(13,13,13)] [/rgb(13,13,13)][rgb(5,5,5)] [/rgb(5,5,5)][rgb(0,0,0)]                   [/rgb(0,0,0)]",
    ]

def display_colored_art(justify):
    """显示彩色PAW爪印"""
    for line in colored_art:
        console.print(Align.center(line))